@@ -1,5 +1,6 @@
-#This is Jonathan's code, we just added a wrapper.
 import docassemble.base.functions
+import re
+
 class shortenMe:
   def __init__(self, originalURL):
     self.shortenedURL = docassemble.base.functions.temp_redirect(originalURL, 60*60*24*7, False, False)
